==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-desktop/translations/dde-desktop_sk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.1">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3117"/>
        <source>Icon size</source>
        <translation>Veľkosť ikony</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3125"/>
        <source>Auto merge</source>
        <translation>Automaticky zlúčiť</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3137"/>
        <source>Auto arrange</source>
        <translation>Automaticky usporiadať</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3174"/>
        <source>Corner Settings</source>
        <translation>Nastavenia rohov</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3183"/>
        <location filename="../view/canvasgridview.cpp" line="3188"/>
        <source>Set Wallpaper</source>
        <translation>Nastaviť pozadie</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3186"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Pozadie a šetrič obrazovky</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3364"/>
        <source>Properties</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3165"/>
        <source>Display Settings</source>
        <translation>Nastavenie zobrazenia</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="37"/>
        <source>Tiny</source>
        <translation>Maličké</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="38"/>
        <source>Small</source>
        <translation>Malé</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="39"/>
        <source>Medium</source>
        <translation>Stredné</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="40"/>
        <source>Large</source>
        <translation>Veľké</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="41"/>
        <source>Super large</source>
        <translation>Veľmi veľké</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="163"/>
        <source>Desktop</source>
        <translation>Plocha</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="718"/>
        <source>Wallpaper Slideshow</source>
        <translation>Slideshow pozadia</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="764"/>
        <source>When login</source>
        <translation>Pri prihlasovaní</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="766"/>
        <source>When wakeup</source>
        <translation>Pri prebudení</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="818"/>
        <source>Require a password on wakeup</source>
        <translation>Vyžadovať heslo pri prebudení</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="850"/>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="852"/>
        <source>Wait:</source>
        <translation>Čakajte:</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="885"/>
        <source>Wallpaper</source>
        <translation>Pozadie</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="897"/>
        <source>Screensaver</source>
        <translation>Šetrič obrazovky</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="962"/>
        <source>Loading wallpapers...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="964"/>
        <source>Loading screensavers...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1021"/>
        <source>Only desktop</source>
        <translation>Iba pracovná plocha</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1022"/>
        <source>Only lock screen</source>
        <translation>Iba obrazovka zamknutia</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1095"/>
        <source>Apply</source>
        <translation>Vykonať</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="274"/>
        <location filename="../view/watermaskframe.cpp" line="275"/>
        <source>Not authorized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="285"/>
        <location filename="../view/watermaskframe.cpp" line="286"/>
        <source>In trial period</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-file-manager_5.5.10.orig.tar.xz: dde-file-manager-5.5.10/src/dde-desktop/translations/dde-desktop_sk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sk">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3384"/>
        <source>Icon size</source>
        <translation>Veľkosť ikony</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3392"/>
        <source>Auto merge</source>
        <translation>Automaticky zlúčiť</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3404"/>
        <source>Auto arrange</source>
        <translation>Automaticky usporiadať</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3441"/>
        <source>Corner Settings</source>
        <translation>Nastavenia rohov</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3450"/>
        <location filename="../view/canvasgridview.cpp" line="3455"/>
        <source>Set Wallpaper</source>
        <translation>Nastaviť pozadie</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3453"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Pozadie a šetrič obrazovky</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3632"/>
        <source>Properties</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3432"/>
        <source>Display Settings</source>
        <translation>Nastavenie zobrazenia</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="37"/>
        <source>Tiny</source>
        <translation>Maličké</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="38"/>
        <source>Small</source>
        <translation>Malé</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="39"/>
        <source>Medium</source>
        <translation>Stredné</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="40"/>
        <source>Large</source>
        <translation>Veľké</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="41"/>
        <source>Super large</source>
        <translation>Veľmi veľké</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="169"/>
        <source>Desktop</source>
        <translation>Plocha</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="725"/>
        <source>Wallpaper Slideshow</source>
        <translation>Slideshow pozadia</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="771"/>
        <source>When login</source>
        <translation>Pri prihlasovaní</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="773"/>
        <source>When wakeup</source>
        <translation>Pri prebudení</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="825"/>
        <source>Require a password on wakeup</source>
        <translation>Vyžadovať heslo pri prebudení</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="857"/>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="859"/>
        <source>Wait:</source>
        <translation>Čakajte:</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="892"/>
        <source>Wallpaper</source>
        <translation>Pozadie</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="904"/>
        <source>Screensaver</source>
        <translation>Šetrič obrazovky</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="969"/>
        <source>Loading wallpapers...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="971"/>
        <source>Loading screensavers...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1028"/>
        <source>Desktop</source>
        <comment>button</comment>
        <translation>Plocha</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1029"/>
        <source>Lock Screen</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1030"/>
        <source>Both</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1105"/>
        <source>Apply</source>
        <comment>button</comment>
        <translation>Vykonať</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="390"/>
        <location filename="../view/watermaskframe.cpp" line="391"/>
        <source>Not authorized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="401"/>
        <location filename="../view/watermaskframe.cpp" line="402"/>
        <source>In trial period</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
